==> _private_core_network-0.0.75.tar.gz: lib/network_resources/model/ticket.dart <==
class ListTicket {
  List<Status>? status;
  List<Ticket>? values;

  ListTicket({this.status, this.values});

  ListTicket.fromJson(Map<String, dynamic> json) {
    if (json["status"] is List) {
      status = json["status"] == null
          ? null
          : (json["status"] as List).map((e) => Status.fromJson(e)).toList();
    }
    if (json["values"] is List) {
      values = json["values"] == null
          ? null
          : (json["values"] as List).map((e) => Ticket.fromJson(e)).toList();
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    if (status != null) {
      _data["status"] = status?.map((e) => e.toJson()).toList();
    }
    if (values != null) {
      _data["values"] = values?.map((e) => e.toJson()).toList();
    }
    return _data;
  }
}

class Ticket {
  Ticket1? ticket;
  List<dynamic>? agent;
  Customer? customer;
  Product? product;
  Place? place;
  Status1? status;
  _ProblemType? problemType;
  int? platformId;
  Answer? answer;

  Ticket(
      {this.ticket,
      this.agent,
      this.customer,
      this.product,
      this.place,
      this.status,
      this.problemType,
      this.platformId,
      this.answer});

  Ticket.fromJson(Map<String, dynamic> json) {
    if (json["ticket"] is Map) {
      ticket = json["ticket"] == null ? null : Ticket1.fromJson(json["ticket"]);
    }
    if (json["agent"] is List) {
      agent = json["agent"] ?? [];
    }
    if (json["customer"] is Map) {
      customer =
          json["customer"] == null ? null : Customer.fromJson(json["customer"]);
    }
    if (json["product"] is Map) {
      product =
          json["product"] == null ? null : Product.fromJson(json["product"]);
    }
    if (json["place"] is Map) {
      place = json["place"] == null ? null : Place.fromJson(json["place"]);
    }
    if (json["status"] is Map) {
      status = json["status"] == null ? null : Status1.fromJson(json["status"]);
    }
    if (json["problemType"] is Map) {
      problemType = json["problemType"] == null
          ? null
          : _ProblemType.fromJson(json["problemType"]);
    }
    if (json["platformId"] is int) {
      platformId = json["platformId"];
    }
    if (json["answer"] is Map) {
      answer = json["answer"] == null ? null : Answer.fromJson(json["answer"]);
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    if (ticket != null) {
      _data["ticket"] = ticket?.toJson();
    }
    if (agent != null) {
      _data["agent"] = agent;
    }
    if (customer != null) {
      _data["customer"] = customer?.toJson();
    }
    if (product != null) {
      _data["product"] = product?.toJson();
    }
    if (place != null) {
      _data["place"] = place?.toJson();
    }
    if (status != null) {
      _data["status"] = status?.toJson();
    }
    if (problemType != null) {
      _data["problemType"] = problemType?.toJson();
    }
    _data["platformId"] = platformId;
    if (answer != null) {
      _data["answer"] = answer?.toJson();
    }
    return _data;
  }
}

class Answer {
  int? numberOfAnswer;
  String? avatarURL;
  String? firstName;
  String? lastName;
  dynamic lastCreatedAt;

  Answer({this.numberOfAnswer, this.lastCreatedAt});

  Answer.fromJson(Map<String, dynamic> json) {
    if (json["numberOfAnswer"] is int) {
      numberOfAnswer = json["numberOfAnswer"];
    }
    if (json["avatarURL"] is String) {
      avatarURL = json["avatarURL"];
    }
    if (json["firstName"] is String) {
      firstName = json["firstName"];
    }
    if (json["lastName"] is String) {
      lastName = json["lastName"];
    }
    lastCreatedAt = json["lastCreatedAt"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["numberOfAnswer"] = numberOfAnswer;
    _data["avatarURL"] = avatarURL;
    _data["firstName"] = firstName;
    _data["lastName"] = lastName;
    _data["lastCreatedAt"] = lastCreatedAt;
    return _data;
  }
}

class _ProblemType {
  int? id;
  int? problemTypeId;
  String? label;

  _ProblemType({this.id, this.problemTypeId, this.label});

  _ProblemType.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) {
      id = json["id"];
    }
    if (json["problemTypeId"] is int) {
      problemTypeId = json["problemTypeId"];
    }
    if (json["label"] is String) {
      label = json["label"];
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["id"] = id;
    _data["problemTypeId"] = problemTypeId;
    _data["label"] = label;
    return _data;
  }
}

class Status1 {
  int? id;
  String? label;

  Status1({this.id, this.label});

  Status1.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) {
      id = json["id"];
    }
    if (json["label"] is String) {
      label = json["label"];
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["id"] = id;
    _data["label"] = label;
    return _data;
  }
}

class Place {
  int? id;
  String? street1;
  String? zip;
  String? city;
  String? state;
  String? country;
  dynamic countryCode;
  String? phone;
  double? lat;
  double? lng;

  Place(
      {this.id,
      this.street1,
      this.zip,
      this.city,
      this.state,
      this.country,
      this.countryCode,
      this.phone,
      this.lat,
      this.lng});

  Place.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) {
      id = json["id"];
    }
    if (json["street1"] is String) {
      street1 = json["street1"];
    }
    if (json["zip"] is String) {
      zip = json["zip"];
    }
    if (json["city"] is String) {
      city = json["city"];
    }
    if (json["state"] is String) {
      state = json["state"];
    }
    if (json["country"] is String) {
      country = json["country"];
    }
    countryCode = json["countryCode"];
    if (json["phone"] is String) {
      phone = json["phone"];
    }
    if (json["lat"] is double) {
      lat = json["lat"];
    }
    if (json["lng"] is double) {
      lng = json["lng"];
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["id"] = id;
    _data["street1"] = street1;
    _data["zip"] = zip;
    _data["city"] = city;
    _data["state"] = state;
    _data["country"] = country;
    _data["countryCode"] = countryCode;
    _data["phone"] = phone;
    _data["lat"] = lat;
    _data["lng"] = lng;
    return _data;
  }
}

class Product {
  int? productId;
  String? serialNumber;
  String? productRefLabel;
  String? productCustomerLabel;
  String? pictureUrl;

  Product(
      {this.productId,
      this.serialNumber,
      this.productRefLabel,
      this.productCustomerLabel,
      this.pictureUrl});

  Product.fromJson(Map<String, dynamic> json) {
    if (json["productId"] is int) {
      productId = json["productId"];
    }
    if (json["serialNumber"] is String) {
      serialNumber = json["serialNumber"];
    }
    if (json["productRefLabel"] is String) {
      productRefLabel = json["productRefLabel"];
    }
    if (json["productCustomerLabel"] is String) {
      productCustomerLabel = json["productCustomerLabel"];
    }
    if (json["pictureUrl"] is String) {
      pictureUrl = json["pictureUrl"];
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["productId"] = productId;
    _data["serialNumber"] = serialNumber;
    _data["productRefLabel"] = productRefLabel;
    _data["productCustomerLabel"] = productCustomerLabel;
    _data["pictureUrl"] = pictureUrl;
    return _data;
  }
}

class Customer {
  int? id;
  String? uniqueId;
  String? displayName;
  String? email;
  String? phone;
  String? thumbnail;
  bool? isUser;

  Customer(
      {this.id,
      this.uniqueId,
      this.displayName,
      this.email,
      this.phone,
      this.thumbnail,
      this.isUser});

  Customer.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) {
      id = json["id"];
    }
    if (json["uniqueId"] is String) {
      uniqueId = json["uniqueId"];
    }
    if (json["displayName"] is String) {
      displayName = json["displayName"];
    }
    if (json["email"] is String) {
      email = json["email"];
    }
    if (json["phone"] is String) {
      phone = json["phone"];
    }
    if (json["thumbnail"] is String) {
      thumbnail = json["thumbnail"];
    }
    if (json["isUser"] is bool) {
      isUser = json["isUser"];
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["id"] = id;
    _data["uniqueId"] = uniqueId;
    _data["displayName"] = displayName;
    _data["email"] = email;
    _data["phone"] = phone;
    _data["thumbnail"] = thumbnail;
    _data["isUser"] = isUser;
    return _data;
  }
}

class Ticket1 {
  int? id;
  String? ticketTitle;
  String? ticketContent;
  int? createdAt;
  int? updatedAt;
  dynamic countryCode;
  String? zip;
  String? arckipelTicketReference;
  String? customerTicketReference;

  Ticket1(
      {this.id,
      this.ticketTitle,
      this.ticketContent,
      this.createdAt,
      this.updatedAt,
      this.countryCode,
      this.zip,
      this.arckipelTicketReference,
      this.customerTicketReference});

  Ticket1.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) {
      id = json["id"];
    }
    if (json["ticketTitle"] is String) {
      ticketTitle = json["ticketTitle"];
    }
    if (json["ticketContent"] is String) {
      ticketContent = json["ticketContent"];
    }
    if (json["createdAt"] is int) {
      createdAt = json["createdAt"];
    }
    if (json["updatedAt"] is int) {
      updatedAt = json["updatedAt"];
    }
    countryCode = json["countryCode"];
    if (json["zip"] is String) {
      zip = json["zip"];
    }
    if (json["arckipelTicketReference"] is String) {
      arckipelTicketReference = json["arckipelTicketReference"];
    }
    if (json["customerTicketReference"] is String) {
      customerTicketReference = json["customerTicketReference"];
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["id"] = id;
    _data["ticketTitle"] = ticketTitle;
    _data["ticketContent"] = ticketContent;
    _data["createdAt"] = createdAt;
    _data["updatedAt"] = updatedAt;
    _data["countryCode"] = countryCode;
    _data["zip"] = zip;
    _data["arckipelTicketReference"] = arckipelTicketReference;
    _data["customerTicketReference"] = customerTicketReference;
    return _data;
  }
}

class Status {
  int? id;
  String? label;
  int? count;

  Status({this.id, this.label, this.count});

  Status.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) {
      id = json["id"];
    }
    if (json["label"] is String) {
      label = json["label"];
    }
    if (json["count"] is int) {
      count = json["count"];
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["id"] = id;
    _data["label"] = label;
    _data["count"] = count;
    return _data;
  }
}

==> _private_core_network-1.3.48.tar.gz: lib/network_resources/model/ticket.dart <==
class ListTicket {
  List<Status>? status;
  List<Ticket>? values;

  ListTicket({this.status, this.values});

  ListTicket.fromJson(Map<String, dynamic> json) {
    if (json["status"] is List) {
      status = json["status"] == null
          ? null
          : (json["status"] as List).map((e) => Status.fromJson(e)).toList();
    }
    if (json["values"] is List) {
      values = json["values"] == null
          ? null
          : (json["values"] as List).map((e) => Ticket.fromJson(e)).toList();
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    if (status != null) {
      data["status"] = status?.map((e) => e.toJson()).toList();
    }
    if (values != null) {
      data["values"] = values?.map((e) => e.toJson()).toList();
    }
    return data;
  }
}

class Ticket {
  Ticket1? ticket;
  List<dynamic>? agent;
  Customer? customer;
  Product? product;
  Place? place;
  Status1? status;
  _ProblemType? problemType;
  int? platformId;
  Answer? answer;

  Ticket(
      {this.ticket,
      this.agent,
      this.customer,
      this.product,
      this.place,
      this.status,
      this.problemType,
      this.platformId,
      this.answer});

  Ticket.fromJson(Map<String, dynamic> json) {
    if (json["ticket"] is Map) {
      ticket = json["ticket"] == null ? null : Ticket1.fromJson(json["ticket"]);
    }
    if (json["agent"] is List) {
      agent = json["agent"] ?? [];
    }
    if (json["customer"] is Map) {
      customer =
          json["customer"] == null ? null : Customer.fromJson(json["customer"]);
    }
    if (json["product"] is Map) {
      product =
          json["product"] == null ? null : Product.fromJson(json["product"]);
    }
    if (json["place"] is Map) {
      place = json["place"] == null ? null : Place.fromJson(json["place"]);
    }
    if (json["status"] is Map) {
      status = json["status"] == null ? null : Status1.fromJson(json["status"]);
    }
    if (json["problemType"] is Map) {
      problemType = json["problemType"] == null
          ? null
          : _ProblemType.fromJson(json["problemType"]);
    }
    if (json["platformId"] is int) {
      platformId = json["platformId"];
    }
    if (json["answer"] is Map) {
      answer = json["answer"] == null ? null : Answer.fromJson(json["answer"]);
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    if (ticket != null) {
      data["ticket"] = ticket?.toJson();
    }
    if (agent != null) {
      data["agent"] = agent;
    }
    if (customer != null) {
      data["customer"] = customer?.toJson();
    }
    if (product != null) {
      data["product"] = product?.toJson();
    }
    if (place != null) {
      data["place"] = place?.toJson();
    }
    if (status != null) {
      data["status"] = status?.toJson();
    }
    if (problemType != null) {
      data["problemType"] = problemType?.toJson();
    }
    data["platformId"] = platformId;
    if (answer != null) {
      data["answer"] = answer?.toJson();
    }
    return data;
  }
}

class Answer {
  int? numberOfAnswer;
  String? avatarURL;
  String? firstName;
  String? lastName;
  dynamic lastCreatedAt;

  Answer({this.numberOfAnswer, this.lastCreatedAt});

  Answer.fromJson(Map<String, dynamic> json) {
    if (json["numberOfAnswer"] is int) {
      numberOfAnswer = json["numberOfAnswer"];
    }
    if (json["avatarURL"] is String) {
      avatarURL = json["avatarURL"];
    }
    if (json["firstName"] is String) {
      firstName = json["firstName"];
    }
    if (json["lastName"] is String) {
      lastName = json["lastName"];
    }
    lastCreatedAt = json["lastCreatedAt"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["numberOfAnswer"] = numberOfAnswer;
    data["avatarURL"] = avatarURL;
    data["firstName"] = firstName;
    data["lastName"] = lastName;
    data["lastCreatedAt"] = lastCreatedAt;
    return data;
  }
}

class _ProblemType {
  int? id;
  int? problemTypeId;
  String? label;

  _ProblemType();

  _ProblemType.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) {
      id = json["id"];
    }
    if (json["problemTypeId"] is int) {
      problemTypeId = json["problemTypeId"];
    }
    if (json["label"] is String) {
      label = json["label"];
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["id"] = id;
    data["problemTypeId"] = problemTypeId;
    data["label"] = label;
    return data;
  }
}

class Status1 {
  int? id;
  String? label;

  Status1({this.id, this.label});

  Status1.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) {
      id = json["id"];
    }
    if (json["label"] is String) {
      label = json["label"];
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["id"] = id;
    data["label"] = label;
    return data;
  }
}

class Place {
  int? id;
  String? street1;
  String? zip;
  String? city;
  String? state;
  String? country;
  dynamic countryCode;
  String? phone;
  double? lat;
  double? lng;

  Place(
      {this.id,
      this.street1,
      this.zip,
      this.city,
      this.state,
      this.country,
      this.countryCode,
      this.phone,
      this.lat,
      this.lng});

  Place.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) {
      id = json["id"];
    }
    if (json["street1"] is String) {
      street1 = json["street1"];
    }
    if (json["zip"] is String) {
      zip = json["zip"];
    }
    if (json["city"] is String) {
      city = json["city"];
    }
    if (json["state"] is String) {
      state = json["state"];
    }
    if (json["country"] is String) {
      country = json["country"];
    }
    countryCode = json["countryCode"];
    if (json["phone"] is String) {
      phone = json["phone"];
    }
    if (json["lat"] is double) {
      lat = json["lat"];
    }
    if (json["lng"] is double) {
      lng = json["lng"];
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["id"] = id;
    data["street1"] = street1;
    data["zip"] = zip;
    data["city"] = city;
    data["state"] = state;
    data["country"] = country;
    data["countryCode"] = countryCode;
    data["phone"] = phone;
    data["lat"] = lat;
    data["lng"] = lng;
    return data;
  }
}

class Product {
  int? productId;
  String? serialNumber;
  String? productRefLabel;
  String? productCustomerLabel;
  String? pictureUrl;

  Product(
      {this.productId,
      this.serialNumber,
      this.productRefLabel,
      this.productCustomerLabel,
      this.pictureUrl});

  Product.fromJson(Map<String, dynamic> json) {
    if (json["productId"] is int) {
      productId = json["productId"];
    }
    if (json["serialNumber"] is String) {
      serialNumber = json["serialNumber"];
    }
    if (json["productRefLabel"] is String) {
      productRefLabel = json["productRefLabel"];
    }
    if (json["productCustomerLabel"] is String) {
      productCustomerLabel = json["productCustomerLabel"];
    }
    if (json["pictureUrl"] is String) {
      pictureUrl = json["pictureUrl"];
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["productId"] = productId;
    data["serialNumber"] = serialNumber;
    data["productRefLabel"] = productRefLabel;
    data["productCustomerLabel"] = productCustomerLabel;
    data["pictureUrl"] = pictureUrl;
    return data;
  }
}

class Customer {
  int? id;
  String? uniqueId;
  String? displayName;
  String? email;
  String? phone;
  String? thumbnail;
  bool? isUser;

  Customer(
      {this.id,
      this.uniqueId,
      this.displayName,
      this.email,
      this.phone,
      this.thumbnail,
      this.isUser});

  Customer.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) {
      id = json["id"];
    }
    if (json["uniqueId"] is String) {
      uniqueId = json["uniqueId"];
    }
    if (json["displayName"] is String) {
      displayName = json["displayName"];
    }
    if (json["email"] is String) {
      email = json["email"];
    }
    if (json["phone"] is String) {
      phone = json["phone"];
    }
    if (json["thumbnail"] is String) {
      thumbnail = json["thumbnail"];
    }
    if (json["isUser"] is bool) {
      isUser = json["isUser"];
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["id"] = id;
    data["uniqueId"] = uniqueId;
    data["displayName"] = displayName;
    data["email"] = email;
    data["phone"] = phone;
    data["thumbnail"] = thumbnail;
    data["isUser"] = isUser;
    return data;
  }
}

class Ticket1 {
  int? id;
  String? ticketTitle;
  String? ticketContent;
  int? createdAt;
  int? updatedAt;
  dynamic countryCode;
  String? zip;
  String? arckipelTicketReference;
  String? customerTicketReference;

  Ticket1(
      {this.id,
      this.ticketTitle,
      this.ticketContent,
      this.createdAt,
      this.updatedAt,
      this.countryCode,
      this.zip,
      this.arckipelTicketReference,
      this.customerTicketReference});

  Ticket1.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) {
      id = json["id"];
    }
    if (json["ticketTitle"] is String) {
      ticketTitle = json["ticketTitle"];
    }
    if (json["ticketContent"] is String) {
      ticketContent = json["ticketContent"];
    }
    if (json["createdAt"] is int) {
      createdAt = json["createdAt"];
    }
    if (json["updatedAt"] is int) {
      updatedAt = json["updatedAt"];
    }
    countryCode = json["countryCode"];
    if (json["zip"] is String) {
      zip = json["zip"];
    }
    if (json["arckipelTicketReference"] is String) {
      arckipelTicketReference = json["arckipelTicketReference"];
    }
    if (json["customerTicketReference"] is String) {
      customerTicketReference = json["customerTicketReference"];
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["id"] = id;
    data["ticketTitle"] = ticketTitle;
    data["ticketContent"] = ticketContent;
    data["createdAt"] = createdAt;
    data["updatedAt"] = updatedAt;
    data["countryCode"] = countryCode;
    data["zip"] = zip;
    data["arckipelTicketReference"] = arckipelTicketReference;
    data["customerTicketReference"] = customerTicketReference;
    return data;
  }
}

class Status {
  int? id;
  String? label;
  int? count;

  Status({this.id, this.label, this.count});

  Status.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) {
      id = json["id"];
    }
    if (json["label"] is String) {
      label = json["label"];
    }
    if (json["count"] is int) {
      count = json["count"];
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["id"] = id;
    data["label"] = label;
    data["count"] = count;
    return data;
  }
}
